==> Wikibase-REL1_35-56582b4.tar.gz: Wikibase/repo/tests/phpunit/includes/UpdateRepo/UpdateRepoOnDeleteJobTest.php <==
<?php

namespace Wikibase\Repo\Tests\UpdateRepo;

use HashSiteStore;
use NullStatsdDataFactory;
use Psr\Log\NullLogger;
use Site;
use SiteLookup;
use Status;
use Title;
use User;
use Wikibase\DataModel\Entity\Item;
use Wikibase\DataModel\Entity\ItemId;
use Wikibase\DataModel\Services\Diff\EntityDiffer;
use Wikibase\DataModel\Services\Diff\EntityPatcher;
use Wikibase\Lib\Tests\MockRepository;
use Wikibase\Repo\EditEntity\EditFilterHookRunner;
use Wikibase\Repo\EditEntity\MediawikiEditEntityFactory;
use Wikibase\Repo\Store\EntityPermissionChecker;
use Wikibase\Repo\Store\EntityTitleStoreLookup;
use Wikibase\Repo\SummaryFormatter;
use Wikibase\Repo\UpdateRepo\UpdateRepoOnDeleteJob;

/**
 * @covers \Wikibase\Repo\UpdateRepo\UpdateRepoOnDeleteJob
 * @covers \Wikibase\Repo\UpdateRepo\UpdateRepoJob
 *
 * @group Wikibase
 * @group WikibaseIntegration
 * @group Database
 *
 * @license GPL-2.0-or-later
 * @author Marius Hoch < hoo@online.de >
 */
class UpdateRepoOnDeleteJobTest extends \MediaWikiTestCase {

	public function testGetSummary() {
		$job = new UpdateRepoOnDeleteJob(
			Title::newMainPage(),
			[
				'siteId' => 'SiteID',
				'title' => 'Test'
			]
		);

		$summary = $job->getSummary();

		$this->assertEquals( 'clientsitelink-remove', $summary->getMessageKey() );
		$this->assertEquals(
			[ 'SiteID' ],
			$summary->getCommentArgs()
		);

		$this->assertEquals(
			[ 'Test' ],
			$summary->getAutoSummaryArgs()
		);
	}

	/**
	 * @param bool $titleExists
	 *
	 * @return SiteLookup
	 */
	private function getSiteLookup( $titleExists ) {
		$enwiki = $this->createMock( Site::class );
		$enwiki->expects( $this->any() )
			->method( 'getGlobalId' )
			->will( $this->returnValue( 'enwiki' ) );
		$enwiki->expects( $this->any() )
			->method( 'normalizePageName' )
			->with( 'Delete me' )
			->will( $this->returnValue( $titleExists ) );

		return new HashSiteStore( [ $enwiki ] );
	}

	/**
	 * @param ItemId $itemId
	 *
	 * @return EntityTitleStoreLookup
	 */
	private function getEntityTitleLookup( ItemId $itemId ) {
		$entityTitleLookup = $this->createMock( EntityTitleStoreLookup::class );
		$entityTitleLookup->expects( $this->any() )
			->method( 'getTitleForId' )
			->with( $itemId )
			->will( $this->returnValue( Title::newFromText( $itemId->getSerialization() ) ) );

		return $entityTitleLookup;
	}

	/**
	 * @return EntityPermissionChecker
	 */
	private function getEntityPermissionChecker() {
		$entityPermissionChecker = $this->createMock( EntityPermissionChecker::class );
		$entityPermissionChecker->expects( $this->any() )
				->method( 'getPermissionStatusForEntity' )
				->will( $this->returnValue( Status::newGood() ) );

		return $entityPermissionChecker;
	}

	/**
	 * @return SummaryFormatter
	 */
	private function getSummaryFormatter() {
		return $this->createMock( SummaryFormatter::class );
	}

	/**
	 * @return EditFilterHookRunner
	 */
	private function getMockEditFitlerHookRunner() {
		$runner = $this->getMockBuilder( EditFilterHookRunner::class )
			->setMethods( [ 'run' ] )
			->disableOriginalConstructor()
			->getMock();
		$runner->expects( $this->any() )
			->method( 'run' )
			->will( $this->returnValue( Status::newGood() ) );
		return $runner;
	}

	public function runProvider() {
		return [
			[ true, false, 'Delete me' ],
			// The title on client still exists, so don't unlink
			[ false, true, 'Delete me' ],
			// The title in the repo item is not the one we want to unlink, don't unlink
			[ false, false, 'Something changed' ]
		];
	}

	/**
	 * @dataProvider runProvider
	 *
	 * @param bool $expected
	 * @param bool $titleExists
	 * @param string $oldTitle
	 */
	public function testRun( $expected, $titleExists, $oldTitle ) {
		$item = new Item();
		$item->getSiteLinkList()->addNewSiteLink( 'enwiki', 'Delete me', [ new ItemId( 'Q42' ) ] );

		$mockRepository = new MockRepository();

		$user = User::newFromName( 'UpdateRepo' );

		// Needed as UpdateRepoOnDeleteJob instantiates a User object
		$user->addToDatabase();

		$mockRepository->saveEntity( $item, 'UpdateRepoOnDeleteJobTest', $user, EDIT_NEW );

		$params = [
			'siteId' => 'enwiki',
			'entityId' => $item->getId()->getSerialization(),
			'title' => $oldTitle,
			'user' => $user->getName()
		];

		$job = new UpdateRepoOnDeleteJob( Title::newMainPage(), $params );
		$job->initServices(
			$mockRepository,
			$mockRepository,
			$this->getSummaryFormatter(),
			new NullLogger(),
			$this->getSiteLookup( $titleExists ),
			new MediawikiEditEntityFactory(
				$this->getEntityTitleLookup( $item->getId() ),
				$mockRepository,
				$mockRepository,
				$this->getEntityPermissionChecker(),
				new EntityDiffer(),
				new EntityPatcher(),
				$this->getMockEditFitlerHookRunner(),
				new NullStatsdDataFactory(),
				PHP_INT_MAX
			)
		);

		$job->run();

		$item = $mockRepository->getEntity( $item->getId() );

		$this->assertSame(
			!$expected,
			$item->getSiteLinkList()->hasLinkWithSiteId( 'enwiki' ),
			'Sitelink has been removed.'
		);
	}

}

==> Wikibase-REL1_38-132412b.tar.gz: Wikibase/repo/tests/phpunit/includes/UpdateRepo/UpdateRepoOnDeleteJobTest.php <==
<?php

namespace Wikibase\Repo\Tests\UpdateRepo;

use HashSiteStore;
use MediaWikiIntegrationTestCase;
use NullStatsdDataFactory;
use Psr\Log\NullLogger;
use Site;
use SiteLookup;
use Status;
use Title;
use User;
use Wikibase\DataModel\Entity\Item;
use Wikibase\DataModel\Entity\ItemId;
use Wikibase\DataModel\Services\Diff\EntityDiffer;
use Wikibase\DataModel\Services\Diff\EntityPatcher;
use Wikibase\Lib\SettingsArray;
use Wikibase\Lib\Tests\MockRepository;
use Wikibase\Repo\EditEntity\EditFilterHookRunner;
use Wikibase\Repo\EditEntity\MediawikiEditEntityFactory;
use Wikibase\Repo\Store\EntityPermissionChecker;
use Wikibase\Repo\Store\EntityTitleStoreLookup;
use Wikibase\Repo\SummaryFormatter;
use Wikibase\Repo\UpdateRepo\UpdateRepoOnDeleteJob;

/**
 * @covers \Wikibase\Repo\UpdateRepo\UpdateRepoOnDeleteJob
 * @covers \Wikibase\Repo\UpdateRepo\UpdateRepoJob
 *
 * @group Wikibase
 * @group WikibaseIntegration
 * @group Database
 *
 * @license GPL-2.0-or-later
 * @author Marius Hoch < hoo@online.de >
 */
class UpdateRepoOnDeleteJobTest extends MediaWikiIntegrationTestCase {

	public function testGetSummary() {
		$job = new UpdateRepoOnDeleteJob(
			Title::newMainPage(),
			[
				'siteId' => 'SiteID',
				'title' => 'Test'
			]
		);

		$summary = $job->getSummary();

		$this->assertEquals( 'clientsitelink-remove', $summary->getMessageKey() );
		$this->assertEquals(
			[ 'SiteID' ],
			$summary->getCommentArgs()
		);

		$this->assertEquals(
			[ 'Test' ],
			$summary->getAutoSummaryArgs()
		);
	}

	private function getSiteLookup( bool $titleExists ): SiteLookup {
		$enwiki = $this->createMock( Site::class );
		$enwiki->method( 'getGlobalId' )
			->willReturn( 'enwiki' );
		$enwiki->method( 'normalizePageName' )
			->with( 'Delete me' )
			->willReturn( $titleExists );

		return new HashSiteStore( [ $enwiki ] );
	}

	private function getEntityTitleLookup( ItemId $itemId ): EntityTitleStoreLookup {
		$entityTitleLookup = $this->createMock( EntityTitleStoreLookup::class );
		$entityTitleLookup->method( 'getTitleForId' )
			->with( $itemId )
			->willReturn( Title::newFromTextThrow( $itemId->getSerialization() ) );

		return $entityTitleLookup;
	}

	private function getEntityPermissionChecker(): EntityPermissionChecker {
		$entityPermissionChecker = $this->createMock( EntityPermissionChecker::class );
		$entityPermissionChecker->method( 'getPermissionStatusForEntity' )
				->willReturn( Status::newGood() );

		return $entityPermissionChecker;
	}

	private function getSummaryFormatter(): SummaryFormatter {
		$summaryFormatter = $this->createMock( SummaryFormatter::class );
		$summaryFormatter->method( 'formatSummary' )->willReturn( '' );

		return $summaryFormatter;
	}

	private function getMockEditFitlerHookRunner(): EditFilterHookRunner {
		$runner = $this->getMockBuilder( EditFilterHookRunner::class )
			->onlyMethods( [ 'run' ] )
			->disableOriginalConstructor()
			->getMock();
		$runner->method( 'run' )
			->willReturn( Status::newGood() );
		return $runner;
	}

	public function runProvider(): iterable {
		return [
			[ true, false, 'Delete me' ],
			// The title on client still exists, so don't unlink
			[ false, true, 'Delete me' ],
			// The title in the repo item is not the one we want to unlink, don't unlink
			[ false, false, 'Something changed' ]
		];
	}

	/**
	 * @dataProvider runProvider
	 */
	public function testRun( bool $expected, bool $titleExists, string $oldTitle ) {
		$item = new Item();
		$item->getSiteLinkList()->addNewSiteLink( 'enwiki', 'Delete me', [ new ItemId( 'Q42' ) ] );

		$mockRepository = new MockRepository();

		$user = User::newFromName( 'UpdateRepo' );

		// Needed as UpdateRepoOnDeleteJob instantiates a User object
		$user->addToDatabase();

		$mockRepository->saveEntity( $item, 'UpdateRepoOnDeleteJobTest', $user, EDIT_NEW );

		$params = [
			'siteId' => 'enwiki',
			'entityId' => $item->getId()->getSerialization(),
			'title' => $oldTitle,
			'user' => $user->getName()
		];
		$tags = [ 'tag 1', 'tag 2' ];

		$job = new UpdateRepoOnDeleteJob( Title::newMainPage(), $params );
		$job->initServices(
			$mockRepository,
			$mockRepository,
			$this->getSummaryFormatter(),
			new NullLogger(),
			$this->getSiteLookup( $titleExists ),
			new MediawikiEditEntityFactory(
				$this->getEntityTitleLookup( $item->getId() ),
				$mockRepository,
				$mockRepository,
				$this->getEntityPermissionChecker(),
				new EntityDiffer(),
				new EntityPatcher(),
				$this->getMockEditFitlerHookRunner(),
				new NullStatsdDataFactory(),
				$this->getServiceContainer()->getUserOptionsLookup(),
				PHP_INT_MAX
			),
			new SettingsArray( [
				'updateRepoTags' => $tags,
			] )
		);

		$job->run();

		$item = $mockRepository->getEntity( $item->getId() );

		$this->assertSame(
			!$expected,
			$item->getSiteLinkList()->hasLinkWithSiteId( 'enwiki' ),
			'Sitelink has been removed.'
		);

		if ( $expected ) {
			$this->assertSame(
				$tags,
				$mockRepository->getLatestLogEntryFor( $item->getId() )['tags'],
				'Edit has been tagged.'
			);
		}
	}

}
